@@ -1,7 +1,7 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2003-2004 Novell, Inc. (www.novell.com)
+ *  Copyright 2003-2005 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -93,6 +93,9 @@ static GnomeWPItem * gnome_wp_add_image (GnomeWPCapplet * capplet,
 					 const gchar * filename) {
   GnomeWPItem * item;
 
+  if (!g_utf8_validate (filename, -1, NULL))
+    return NULL;
+
   item = g_hash_table_lookup (capplet->wphash, filename);
   if (item != NULL) {
     if (item->deleted) {
